@@ -62,6 +62,10 @@ struct _AgsUiProviderInterface
   GtkWidget* (*get_animation_window)(AgsUiProvider *ui_provider);
   void (*set_animation_window)(AgsUiProvider *ui_provider,
 			       GtkWidget *animation_window);
+
+  GList* (*get_machine)(AgsUiProvider *ui_provider);
+  void (*set_machine)(AgsUiProvider *ui_provider,
+		      GList *machine);
 };
 
 GType ags_ui_provider_get_type();
@@ -86,4 +90,8 @@ GtkWidget* ags_ui_provider_get_animation_window(AgsUiProvider *ui_provider);
 void ags_ui_provider_set_animation_window(AgsUiProvider *ui_provider,
 					  GtkWidget *animation_window);
 
+GList* ags_ui_provider_get_machine(AgsUiProvider *ui_provider);
+void ags_ui_provider_set_machine(AgsUiProvider *ui_provider,
+				 GList *machine);
+
 #endif /*__AGS_UI_PROVIDER_H__*/
