@@ -19,6 +19,10 @@
 
 #include <ags/X/machine/ags_audiorec_callbacks.h>
 
+#include <ags/libags.h>
+#include <ags/libags-audio.h>
+#include <ags/libags-gui.h>
+
 #include <ags/X/ags_window.h>
 
 #include <ags/i18n.h>
