@@ -58,9 +58,16 @@ struct _AgsFFPlayer
   gchar *name;
   gchar *xml_type;
 
+  AgsAudioContainer *audio_container;
+
+  GtkEntry *filename;
   GtkButton *open;
-  GtkWidget *open_dialog;
   
+  AgsSF2Loader *sf2_loader;
+
+  gint position;
+  GtkLabel *loading;
+
   guint control_width;
   guint control_height;
   
@@ -68,9 +75,10 @@ struct _AgsFFPlayer
   GtkHScrollbar *hscrollbar;
   GtkAdjustment *hadjustment;
 
-  AgsAudioContainer *audio_container;
   GtkComboBoxText *preset;
   GtkComboBoxText *instrument;
+
+  GtkWidget *open_dialog;
 };
 
 struct _AgsFFPlayerClass
@@ -89,6 +97,8 @@ void ags_ffplayer_open_filename(AgsFFPlayer *ffplayer,
 void ags_ffplayer_load_preset(AgsFFPlayer *ffplayer);
 void ags_ffplayer_load_instrument(AgsFFPlayer *ffplayer);
 
+gboolean ags_ffplayer_sf2_loader_completed_timeout(AgsFFPlayer *ffplayer);
+
 AgsFFPlayer* ags_ffplayer_new(GObject *soundcard);
 
 #endif /*__AGS_FFPLAYER_H__*/
