@@ -23,6 +23,8 @@
 #include <glib.h>
 #include <glib-object.h>
 
+#include <pthread.h>
+
 #include <alsa/asoundlib.h>
 
 #define AGS_TYPE_BUFFER                (ags_buffer_get_type())
@@ -52,7 +54,7 @@ typedef enum{
 
 struct _AgsBuffer
 {
-  GObject object;
+  GObject gobject;
 
   guint flags;
 
@@ -73,7 +75,7 @@ struct _AgsBuffer
 
 struct _AgsBufferClass
 {
-  GObjectClass object;
+  GObjectClass gobject;
 };
 
 GType ags_buffer_get_type();
