@@ -29,7 +29,8 @@
 #include <ags/audio/audio-unit/ags_audio_unit_port.h>
 #include <ags/audio/audio-unit/ags_audio_unit_devout.h>
 #include <ags/audio/audio-unit/ags_audio_unit_devin.h>
-#include <ags/audio/audio-unit/ags_audio_unit_midiin.h>
+
+#include <stdlib.h>
 
 #include <ags/i18n.h>
 
@@ -277,11 +278,7 @@ ags_audio_unit_client_set_property(GObject *gobject,
   audio_unit_client = AGS_AUDIO_UNIT_CLIENT(gobject);
 
   /* get audio-unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
 
   switch(prop_id){
   case PROP_AUDIO_UNIT_SERVER:
@@ -392,11 +389,7 @@ ags_audio_unit_client_get_property(GObject *gobject,
   audio_unit_client = AGS_AUDIO_UNIT_CLIENT(gobject);
 
   /* get audio-unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
   
   switch(prop_id){
   case PROP_AUDIO_UNIT_SERVER:
@@ -519,11 +512,6 @@ ags_audio_unit_client_finalize(GObject *gobject)
     g_object_unref(audio_unit_client->audio_unit_server);
   }
 
-  /* core audio graph */
-  if(audio_unit_client->graph != NULL){
-    free(audio_unit_client->graph);
-  }
-
   /* device */
   if(audio_unit_client->device != NULL){
     g_list_free_full(audio_unit_client->device,
@@ -552,11 +540,7 @@ ags_audio_unit_client_get_uuid(AgsConnectable *connectable)
   audio_unit_client = AGS_AUDIO_UNIT_CLIENT(connectable);
 
   /* get audio_unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
 
   /* get UUID */
   pthread_mutex_lock(audio_unit_client_mutex);
@@ -586,11 +570,7 @@ ags_audio_unit_client_is_ready(AgsConnectable *connectable)
   audio_unit_client = AGS_AUDIO_UNIT_CLIENT(connectable);
 
   /* get audio_unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
 
   /* check is added */
   pthread_mutex_lock(audio_unit_client_mutex);
@@ -673,11 +653,7 @@ ags_audio_unit_client_is_connected(AgsConnectable *connectable)
   audio_unit_client = AGS_AUDIO_UNIT_CLIENT(connectable);
 
   /* get audio_unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
 
   /* check is connected */
   pthread_mutex_lock(audio_unit_client_mutex);
@@ -707,11 +683,7 @@ ags_audio_unit_client_connect(AgsConnectable *connectable)
   ags_audio_unit_client_set_flags(audio_unit_client, AGS_AUDIO_UNIT_CLIENT_CONNECTED);
 
   /* get audio_unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
 
   /* port */
   pthread_mutex_lock(audio_unit_client_mutex);
@@ -749,11 +721,7 @@ ags_audio_unit_client_disconnect(AgsConnectable *connectable)
   ags_audio_unit_client_unset_flags(audio_unit_client, AGS_AUDIO_UNIT_CLIENT_CONNECTED);
 
   /* get audio_unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
 
   /* port */
   pthread_mutex_lock(audio_unit_client_mutex);
@@ -810,11 +778,7 @@ ags_audio_unit_client_test_flags(AgsAudioUnitClient *audio_unit_client, guint fl
   }
 
   /* get audio_unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
 
   /* test */
   pthread_mutex_lock(audio_unit_client_mutex);
@@ -845,11 +809,7 @@ ags_audio_unit_client_set_flags(AgsAudioUnitClient *audio_unit_client, guint fla
   }
 
   /* get audio_unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
 
   //TODO:JK: add more?
 
@@ -880,11 +840,7 @@ ags_audio_unit_client_unset_flags(AgsAudioUnitClient *audio_unit_client, guint f
   }
 
   /* get audio_unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
 
   //TODO:JK: add more?
 
@@ -912,8 +868,7 @@ ags_audio_unit_client_find_uuid(GList *audio_unit_client,
 				gchar *client_uuid)
 {
   while(audio_unit_client != NULL){
-    if(AGS_AUDIO_UNIT_CLIENT(audio_unit_client->data)->graph != NULL &&
-       !g_ascii_strcasecmp(AGS_AUDIO_UNIT_CLIENT(audio_unit_client->data)->client_uuid,
+    if(!g_ascii_strcasecmp(AGS_AUDIO_UNIT_CLIENT(audio_unit_client->data)->client_uuid,
 			   client_uuid)){
       return(audio_unit_client);
     }
@@ -947,17 +902,12 @@ ags_audio_unit_client_find(GList *audio_unit_client,
     current_audio_unit_client = AGS_AUDIO_UNIT_CLIENT(audio_unit_client->data);
     
     /* get audio_unit client mutex */
-    pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-    audio_unit_client_mutex = current_audio_unit_client->obj_mutex;
-  
-    pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+    audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(current_audio_unit_client);
 
     /* check uuid */
     pthread_mutex_lock(audio_unit_client_mutex);
     
-    success = (current_audio_unit_client->graph != NULL &&
-	       !g_ascii_strcasecmp(current_audio_unit_client->client_name,
+    success = (!g_ascii_strcasecmp(current_audio_unit_client->client_name,
 				   client_name)) ? TRUE: FALSE;
 
     pthread_mutex_unlock(audio_unit_client_mutex);
@@ -1002,16 +952,12 @@ ags_audio_unit_client_open(AgsAudioUnitClient *audio_unit_client,
   }
 
   /* get audio_unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
 
   /* check already open */
   pthread_mutex_lock(audio_unit_client_mutex);
 
-  if(audio_unit_client->graph != NULL){
+  if(ags_audio_unit_client_test_flags(audio_unit_client, AGS_AUDIO_UNIT_CLIENT_ACTIVATED)){
     pthread_mutex_unlock(audio_unit_client_mutex);
 
     g_message("Advanced Gtk+ Sequencer audio-unit client already open");
@@ -1030,24 +976,7 @@ ags_audio_unit_client_open(AgsAudioUnitClient *audio_unit_client,
 	       NULL);
 
   /* get audio_unit server mutex */
-  pthread_mutex_lock(ags_audio_unit_server_get_class_mutex());
-  
-  audio_unit_server_mutex = audio_unit_server->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_server_get_class_mutex());
-
-#ifdef AGS_WITH_AUDIO_UNIT
-  audio_unit_client->graph = (AUGraph *) malloc(sizeof(AUGraph));
-  memset(audio_unit_client->graph, 0, sizeof(AUGraph));
-  
-  retval = NewAUGraph(audio_unit_client->graph);
-
-  if(retval != noErr){
-    free(audio_unit_client->graph);
-    
-    audio_unit_client->graph = NULL;
-  }
-#endif
+  audio_unit_server_mutex = AGS_AUDIO_UNIT_SERVER_GET_OBJ_MUTEX(audio_unit_server);
 }
 
 /**
@@ -1061,12 +990,6 @@ ags_audio_unit_client_open(AgsAudioUnitClient *audio_unit_client,
 void
 ags_audio_unit_client_activate(AgsAudioUnitClient *audio_unit_client)
 {
-#ifdef AGS_WITH_AUDIO_UNIT
-  AUGraph *graph;
-#else
-  gpointer graph;
-#endif
-
   GList *port_start, *port;
   
   int ret;
@@ -1078,21 +1001,9 @@ ags_audio_unit_client_activate(AgsAudioUnitClient *audio_unit_client)
   }
   
   /* get audio_unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
 
-  /* get graph */
-  pthread_mutex_lock(audio_unit_client_mutex);
-
-  graph = audio_unit_client->graph;
-  
-  pthread_mutex_unlock(audio_unit_client_mutex);
-
-  if(ags_audio_unit_client_test_flags(audio_unit_client, AGS_AUDIO_UNIT_CLIENT_ACTIVATED) ||
-     graph == NULL){
+  if(ags_audio_unit_client_test_flags(audio_unit_client, AGS_AUDIO_UNIT_CLIENT_ACTIVATED)){
     return;
   }  
 
@@ -1136,12 +1047,6 @@ ags_audio_unit_client_activate(AgsAudioUnitClient *audio_unit_client)
 void
 ags_audio_unit_client_deactivate(AgsAudioUnitClient *audio_unit_client)
 {
-#ifdef AGS_WITH_AUDIO_UNIT
-  AUGraph *graph;
-#else
-  gpointer graph;
-#endif
-
   pthread_mutex_t *audio_unit_client_mutex;
 
   if(!AGS_IS_AUDIO_UNIT_CLIENT(audio_unit_client)){
@@ -1149,33 +1054,7 @@ ags_audio_unit_client_deactivate(AgsAudioUnitClient *audio_unit_client)
   }
   
   /* get audio_unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
-
-  /* get graph */
-  pthread_mutex_lock(audio_unit_client_mutex);
-
-  graph = audio_unit_client->graph;
-  
-  pthread_mutex_unlock(audio_unit_client_mutex);
-
-  if(graph == NULL){
-    return;
-  }
-
-#ifdef AGS_WITH_AUDIO_UNIT
-  AUGraphStop(graph);
-#endif
-  
-  /* set graph */
-  pthread_mutex_lock(audio_unit_client_mutex);
-
-  audio_unit_client->graph = NULL;
-  
-  pthread_mutex_unlock(audio_unit_client_mutex);
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
 
   ags_audio_unit_client_unset_flags(audio_unit_client, AGS_AUDIO_UNIT_CLIENT_ACTIVATED);
 }
@@ -1202,11 +1081,7 @@ ags_audio_unit_client_add_device(AgsAudioUnitClient *audio_unit_client,
   }
 
   /* get audio_unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
 
   /* add device */
   pthread_mutex_lock(audio_unit_client_mutex);
@@ -1240,11 +1115,7 @@ ags_audio_unit_client_remove_device(AgsAudioUnitClient *audio_unit_client,
   }
 
   /* get audio_unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
   
   /* remove */
   pthread_mutex_lock(audio_unit_client_mutex);
@@ -1279,11 +1150,7 @@ ags_audio_unit_client_add_port(AgsAudioUnitClient *audio_unit_client,
   }
   
   /* get audio_unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
 
   /* add port */
   pthread_mutex_lock(audio_unit_client_mutex);
@@ -1317,11 +1184,7 @@ ags_audio_unit_client_remove_port(AgsAudioUnitClient *audio_unit_client,
   }
   
   /* get audio_unit client mutex */
-  pthread_mutex_lock(ags_audio_unit_client_get_class_mutex());
-  
-  audio_unit_client_mutex = audio_unit_client->obj_mutex;
-  
-  pthread_mutex_unlock(ags_audio_unit_client_get_class_mutex());
+  audio_unit_client_mutex = AGS_AUDIO_UNIT_CLIENT_GET_OBJ_MUTEX(audio_unit_client);
 
   /* remove port */
   pthread_mutex_lock(audio_unit_client_mutex);
