@@ -33,10 +33,14 @@
 #if defined(__APPLE__) || defined(__FreeBSD__) || defined(__DragonFly__)
 #include <machine/endian.h>
 #else
+#ifndef AGS_W32API
 #include <endian.h>
 #endif
+#endif
 
+#ifndef AGS_W32API
 #include <dlfcn.h>
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -621,10 +625,23 @@ ags_play_dssi_audio_load(AgsPlayDssiAudio *play_dssi_audio)
 
   /* dssi descriptor function - dlsym */
   if(plugin_so){
+    gboolean success;
+    
+    success = FALSE;
+
+#ifdef AGS_W32API
+    dssi_descriptor = (DSSI_Descriptor_Function) GetProcAddress(plugin_so,
+								"dssi_descriptor");
+    
+    success = (!dssi_descriptor) ? FALSE: TRUE;
+#else
     dssi_descriptor = (DSSI_Descriptor_Function) dlsym(plugin_so,
 						       "dssi_descriptor");
+  
+    success = (dlerror() == NULL) ? TRUE: FALSE;
+#endif
 
-    if(dlerror() == NULL && dssi_descriptor){
+    if(success && dssi_descriptor){
       pthread_mutex_lock(recall_mutex);
       
       play_dssi_audio->plugin_descriptor = 
