@@ -67,6 +67,9 @@ struct _AgsMainLoopInterface
   void (*sync_counter_inc)(AgsMainLoop *main_loop, guint tic);
   void (*sync_counter_dec)(AgsMainLoop *main_loop, guint tic);
   gboolean (*sync_counter_test)(AgsMainLoop *main_loop, guint tic);
+
+  void (*set_sync_tic)(AgsMainLoop *main_loop, guint sync_tic);
+  guint (*get_sync_tic)(AgsMainLoop *main_loop);
 };
 
 GType ags_main_loop_get_type();
@@ -98,4 +101,7 @@ void ags_main_loop_sync_counter_inc(AgsMainLoop *main_loop, guint tic);
 void ags_main_loop_sync_counter_dec(AgsMainLoop *main_loop, guint tic);
 gboolean ags_main_loop_sync_counter_test(AgsMainLoop *main_loop, guint tic);
 
+void ags_main_loop_set_sync_tic(AgsMainLoop *main_loop, guint sync_tic);
+guint ags_main_loop_get_sync_tic(AgsMainLoop *main_loop);
+
 #endif /*__AGS_MAIN_LOOP_H__*/
