@@ -23,7 +23,12 @@
 
 #include <ags/plugin/ags_plugin_port.h>
 
+#if defined(AGS_W32API)
+#include <windows.h>
+#else
 #include <dlfcn.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -387,7 +392,8 @@ ags_ladspa_plugin_load_plugin(AgsBasePlugin *base_plugin)
   unsigned long effect_index;
   unsigned long port_count;
   unsigned long i;
-
+  gboolean success;
+    
   pthread_mutex_t *base_plugin_mutex;
   
   ladspa_plugin = AGS_LADSPA_PLUGIN(base_plugin);  
@@ -398,25 +404,44 @@ ags_ladspa_plugin_load_plugin(AgsBasePlugin *base_plugin)
   /* dlopen */
   pthread_mutex_lock(base_plugin_mutex);
 
+#ifdef AGS_W32API
+  base_plugin->plugin_so = LoadLibrary(base_plugin->filename);
+#else
   base_plugin->plugin_so = dlopen(base_plugin->filename,
 				  RTLD_NOW);
+#endif
   
   if(base_plugin->plugin_so == NULL){
     g_warning("ags_ladspa_plugin.c - failed to load static object file");
     
+#ifndef AGS_W32API    
     dlerror();
-
+#endif
+    
     pthread_mutex_unlock(base_plugin_mutex);
 
     return;
   }
 
-  ladspa_descriptor = (LADSPA_Descriptor_Function) dlsym((void *) base_plugin->plugin_so,
-							 "ladspa_descriptor");
+  success = FALSE;
+    
+#ifdef AGS_W32API
+  base_plugin->plugin_handle = 
+    ladspa_descriptor = (LADSPA_Descriptor_Function) GetProcAddress((void *) base_plugin->plugin_so,
+								    "ladspa_descriptor");
 
+  success = (!ladspa_descriptor) ? FALSE: TRUE;
+#else
+  base_plugin->plugin_handle = 
+    ladspa_descriptor = (LADSPA_Descriptor_Function) dlsym((void *) base_plugin->plugin_so,
+							   "ladspa_descriptor");
+  
+  success = (dlerror() == NULL) ? TRUE: FALSE;
+#endif
+  
   pthread_mutex_unlock(base_plugin_mutex);
   
-  if(dlerror() == NULL && ladspa_descriptor){
+  if(success && ladspa_descriptor){
     gpointer plugin_descriptor;
 
     guint unique_id;
