@@ -27,7 +27,12 @@
 #include <ags/plugin/ags_lv2_log_manager.h>
 #include <ags/plugin/ags_lv2_urid_manager.h>
 
+#if defined(AGS_W32API)
+#include <windows.h>
+#else
 #include <dlfcn.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -550,20 +555,38 @@ ags_lv2ui_plugin_instantiate_with_params(AgsBasePlugin *base_plugin,
   ui_effect_index = 0;
 
   if(ui_plugin_so == NULL){
+    gboolean success;
+    
     g_message("open %s", base_plugin->ui_filename);
     
-    ui_plugin_so = dlopen(base_plugin->ui_filename,
+#ifdef AGS_W32API
+    ui_plugin_so = LoadLibrary(base_plugin->filename);
+#else
+    ui_plugin_so = dlopen(base_plugin->filename,
 			  RTLD_NOW);
+#endif
     
     g_object_set(lv2ui_plugin,
 		 "ui-plugin-so", ui_plugin_so,
 		 NULL);
 
+    success = FALSE;    
+    
+#ifdef AGS_W32API
     base_plugin->ui_plugin_handle = 
-      lv2ui_descriptor = (LV2UI_DescriptorFunction) dlsym(ui_plugin_so,
-							  "lv2ui_descriptor");
+      lv2ui_descriptor = (LV2_Descriptor_Function) GetProcAddress(ui_plugin_so,
+								  "lv2ui_descriptor");
 
-    if(dlerror() == NULL && lv2_descriptor){
+    success = (!lv2_descriptor) ? FALSE: TRUE;
+#else
+    base_plugin->ui_plugin_handle = 
+      lv2ui_descriptor = (LV2_Descriptor_Function) dlsym(ui_plugin_so,
+							 "lv2ui_descriptor");
+
+    success = (dlerror() == NULL) ? TRUE: FALSE;
+#endif
+
+    if(success && lv2_descriptor){
       for(i = 0; (plugin_descriptor = lv2ui_descriptor((uint32_t) i)) != NULL; i++){
 	if(!g_ascii_strcasecmp(plugin_descriptor->URI,
 			       lv2ui_plugin->gui_uri)){
@@ -682,6 +705,7 @@ ags_lv2ui_plugin_instantiate_with_params(AgsBasePlugin *base_plugin,
     nth++;
   
     /* log feature */
+#if 0
     log_feature = (LV2_Log_Log *) malloc(sizeof(LV2_Log_Log));
   
     log_feature->handle = NULL;
@@ -693,7 +717,8 @@ ags_lv2ui_plugin_instantiate_with_params(AgsBasePlugin *base_plugin,
     feature[nth]->data = log_feature;
 
     nth++;
-  
+#endif
+    
     /* event feature */
     event_feature = (LV2_Event_Feature *) malloc(sizeof(LV2_Event_Feature));
   
